@@ -2,13 +2,8 @@ use crate::ctapdef;
 #[allow(unused_imports)]
 use crate::util;
 
-#[cfg(not(target_os = "linux"))]
 use crate::fidokey::*;
 
-// for pi
-#[cfg(target_os = "linux")]
-use crate::fidokey_pi::*;
-
 use std::{thread, time};
 
 //pub const USAGE_PAGE_FIDO: u16 = 0xf1d0;
