@@ -20,21 +20,13 @@ pub fn make_credential(
     pin: Option<&str>,
     rk: bool,
     rkparam: Option<&PublicKeyCredentialUserEntity>,
-    //uv: Option<bool>,
+    uv: Option<bool>,
     extensions: Option<&Vec<Extension>>,
     key_type: Option<CredentialSupportedKeyType>,
 ) -> Result<make_credential_params::Attestation> {
     // init
     let cid = ctaphid::ctaphid_init(device).map_err(Error::msg)?;
 
-    // uv
-    let uv = {
-        match pin {
-            Some(_) => None,
-            None => Some(true),
-        }
-    };
-
     let user_id = {
         if let Some(rkp) = rkparam {
             rkp.id.to_vec()
