@@ -64,7 +64,7 @@ impl fmt::Display for Attestation {
     }
 }
 
-#[derive(Debug, Clone, strum_macros::ToString, AsRefStr)]
+#[derive(Debug, Clone, strum_macros::Display, AsRefStr)]
 pub enum Extension {
     #[strum(serialize = "credProtect")]
     CredProtect(Option<CredentialProtectionPolicy>),
@@ -75,3 +75,15 @@ pub enum Extension {
     #[strum(serialize = "hmac-secret")]
     HmacSecret(Option<bool>),
 }
+
+#[derive(Debug, Copy, Clone)]
+pub enum CredentialSupportedKeyType {
+    Ecdsa256 = -7,
+    Ed25519 = -8,
+}
+
+impl std::default::Default for CredentialSupportedKeyType {
+    fn default() -> Self {
+        Self::Ecdsa256
+    }
+}
